@@ -4,7 +4,7 @@ __author__ = 'Vlad Romanenko'
 
 import os
 import glob
-from Logger import logger
+from zmeiapi.Logger import logger
 
 
 class BumatMaterialObject:
