@@ -2,7 +2,7 @@ __version__ = '0.3.0'
 __author__ = 'Vlad Romanenko'
 
 
-from Logger import logger
+from zmeiapi.Logger import logger
 
 
 class Material:
